@@ -64,7 +64,7 @@ module SiSU_DbImport
   require_relative 'db_columns'                         # db_columns.rb
   require_relative 'db_load_tuple'                      # db_load_tuple.rb
   require_relative 'db_sqltxt'                          # db_sqltxt.rb
-  require_relative 'shared_html_lite'                   # shared_html_lite.rb
+  require_relative 'html_lite_shared'                   # html_lite_shared.rb
   require 'sqlite3'
   class Import < SiSU_DbText::Prepare
     include SiSU_Param
@@ -76,7 +76,7 @@ module SiSU_DbImport
       @opt,@conn,@file_maint,@sql_type=opt,conn,file_maint,sql_type
       @cX=SiSU_Screen::Ansi.new(@opt.act[:color_state][:set]).cX
       @env=SiSU_Env::InfoEnv.new(@opt.fns)
-      @dal="#{@env.processing_path.dal}"
+      @dal="#{@env.processing_path.ao}"
       @fnb=if @opt.fns.empty? \
       or @opt.cmd.empty?
         ''
@@ -121,8 +121,8 @@ module SiSU_DbImport
       @@dl ||=SiSU_Env::InfoEnv.new.digest.length
     end
     def marshal_load
-      require_relative 'dal'                            # dal.rb
-      @dal_array=SiSU_DAL::Source.new(@opt).get            # dal file drawn here
+      require_relative 'ao'                               # ao.rb
+      @ao_array=SiSU_AO::Source.new(@opt).get             # ao file drawn here
       if (@opt.act[:verbose][:set]==:on \
       || @opt.act[:verbose_plus][:set]==:on \
       || @opt.act[:maintenance][:set]==:on)
@@ -142,8 +142,8 @@ module SiSU_DbImport
       if not file_exist
         t_d=[]                                                              # transaction_data
         t_d << db_import_metadata
-        t_d << db_import_documents(@dal_array)
-        t_d << db_import_urls(@dal_array,@fnc)                              #import OID on/off
+        t_d << db_import_documents(@ao_array)
+        t_d << db_import_urls(@ao_array,@fnc)                              #import OID on/off
         t_d=t_d.flatten
         if (@opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on)
@@ -283,12 +283,12 @@ module SiSU_DbImport
       tuple=t.tuple
       tuple
     end
-    def db_import_documents(dal_array)                                     #% import documents - populate main database table, import into substantive database tables (tuple)
+    def db_import_documents(ao_array)                                     #% import documents - populate main database table, import into substantive database tables (tuple)
       begin
         @col[:tid]=@@id_t
         @en,@en_ast,@en_pls,@tuple_array=[],[],[],[]
         @col[:en_a],@col[:en_z]=nil,nil
-        dal_array.each do |data|
+        ao_array.each do |data|
           data.obj.gsub!(/#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}/,'\1')
           data.obj.gsub!(/#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}/,'\1')
           data.obj.gsub!(/#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}/,'\1')
