@@ -396,6 +396,27 @@ module SiSU_Manifest
           id,file='XML DOM',@f.base_filename.xml_dom
           summarize(id,file,pth,rel,url)
         end
+        if FileTest.file?(@f.place_file.xml_docbook_article.dir)==true
+          pth=@f.output_path.xml_docbook_article.dir
+          rel=@f.output_path.xml_docbook_article.rel_sm
+          url=@f.output_path.xml_docbook_article.url
+          id,file='XML Docbook Book',@f.base_filename.xml_docbook_article
+          summarize(id,file,pth,rel,url)
+        end
+        if FileTest.file?(@f.place_file.xml_docbook_book.dir)==true
+          pth=@f.output_path.xml_docbook_book.dir
+          rel=@f.output_path.xml_docbook_book.rel_sm
+          url=@f.output_path.xml_docbook_book.url
+          id,file='XML Docbook Book',@f.base_filename.xml_docbook_book
+          summarize(id,file,pth,rel,url)
+        end
+        if FileTest.file?(@f.place_file.xml_fictionbook.dir)==true
+          pth=@f.output_path.xml_fictionbook.dir
+          rel=@f.output_path.xml_fictionbook.rel_sm
+          url=@f.output_path.xml_fictionbook.url
+          id,file='XML Fictionbook',@f.base_filename.xml_fictionbook
+          summarize(id,file,pth,rel,url)
+        end
         if FileTest.file?(@f.place_file.xml_scaffold_structure_sisu.dir)==true
           pth=@f.output_path.xml_scaffold_structure_sisu.dir
           rel=@f.output_path.xml_scaffold_structure_sisu.rel_sm
@@ -439,6 +460,38 @@ module SiSU_Manifest
           file=@f.base_filename.txt
           summarize(id,file,pth,rel,url)
         end
+        if FileTest.file?(@f.place_file.textile.dir)==true
+          id='Textile text (UTF-8)'
+          pth=@f.output_path.textile.dir
+          rel=@f.output_path.textile.rel_sm
+          url=@f.output_path.textile.url
+          file=@f.base_filename.textile
+          summarize(id,file,pth,rel,url)
+        end
+        if FileTest.file?(@f.place_file.asciidoc.dir)==true
+          id='asciiDoc text (UTF-8)'
+          pth=@f.output_path.asciidoc.dir
+          rel=@f.output_path.asciidoc.rel_sm
+          url=@f.output_path.asciidoc.url
+          file=@f.base_filename.asciidoc
+          summarize(id,file,pth,rel,url)
+        end
+        if FileTest.file?(@f.place_file.markdown.dir)==true
+          id='Markdown text (UTF-8)'
+          pth=@f.output_path.markdown.dir
+          rel=@f.output_path.markdown.rel_sm
+          url=@f.output_path.markdown.url
+          file=@f.base_filename.markdown
+          summarize(id,file,pth,rel,url)
+        end
+        if FileTest.file?(@f.place_file.rst.dir)==true
+          id='rST text (UTF-8)'
+          pth=@f.output_path.rst.dir
+          rel=@f.output_path.rst.rel_sm
+          url=@f.output_path.rst.url
+          file=@f.base_filename.rst
+          summarize(id,file,pth,rel,url)
+        end
         if FileTest.file?("#{@base_path}/#{@md.fns}.tex")==true
           id,file='LaTeX (portrait)',"#{@md.fns}.tex"
           pth,rel,url='','',''
