@@ -327,9 +327,9 @@ element-external_space =
   }
 RELAXNG
     end
-    def rnc_sisu_object_dal
+    def rnc_sisu_object_ao
       @relaxng =<<RELAXNG
-#%% sisu object model: dal
+#%% sisu object model: ao
 #{gpl3_or_later}
 #%% definitions
 # dublin core:
@@ -500,7 +500,7 @@ RELAXNG
       @relaxng =<<RELAXNG
 #% sax output model, part of SiSU and distributed under the same license
 default namespace = ""
-namespace xlink = "http://www.w3.org/1999/xlink"
+namespace xl = "http://www.w3.org/1999/xlink"
 start =
   element document {
     element head {
@@ -510,8 +510,8 @@ start =
            attribute class { xsd:NCName },
            (text
             | element link {
-                attribute xlink:href { xsd:anyURI },
-                attribute xlink:type { xsd:NCName },
+                attribute xl:href { xsd:anyURI },
+                attribute xl:type { xsd:NCName },
                 xsd:anyURI
               })+
          }
@@ -603,10 +603,10 @@ start =
                attribute alt { text }?,
                attribute height { xsd:integer }?,
                attribute width { xsd:integer }?,
-               attribute xlink:actuate { xsd:NCName },
-               attribute xlink:href { text },
-               attribute xlink:show { xsd:NCName },
-               attribute xlink:type { xsd:NCName }
+               attribute xl:actuate { xsd:NCName },
+               attribute xl:href { text },
+               attribute xl:show { xsd:NCName },
+               attribute xl:type { xsd:NCName }
              })+
         }?,
         element table {
@@ -654,8 +654,8 @@ sub = element sub { xsd:NCName }
 sup = element sup { xsd:NCName }
 link =
   element link {
-    attribute xlink:href { xsd:anyURI },
-    attribute xlink:type { xsd:NCName },
+    attribute xl:href { xsd:anyURI },
+    attribute xl:type { xsd:NCName },
     (xsd:anyURI | text | b | i | sup)+
   }
 u = element u { (text | b | i)+ }
@@ -666,7 +666,7 @@ RELAXNG
       @relaxng =<<RELAXNG
 #% dom output model, part of SiSU and distributed under the same license
 default namespace = ""
-namespace xlink = "http://www.w3.org/1999/xlink"
+namespace xl = "http://www.w3.org/1999/xlink"
 start =
   element document {
     element head {
@@ -770,10 +770,10 @@ object =
           | element image {
               attribute height { xsd:integer },
               attribute width { xsd:integer },
-              attribute xlink:actuate { xsd:NCName },
-              attribute xlink:href { text },
-              attribute xlink:show { xsd:NCName },
-              attribute xlink:type { xsd:NCName }
+              attribute xl:actuate { xsd:NCName },
+              attribute xl:href { text },
+              attribute xl:show { xsd:NCName },
+              attribute xl:type { xsd:NCName }
             }
           | element sub { text })+
        })
@@ -786,8 +786,8 @@ sup = element sup { xsd:NCName }
 del = element del { (text | b | i | link)+ }
 link =
   element link {
-    attribute xlink:href { xsd:anyURI },
-    attribute xlink:type { xsd:NCName },
+    attribute xl:href { xsd:anyURI },
+    attribute xl:type { xsd:NCName },
     xsd:anyURI
   }
 endnote =
@@ -814,7 +814,7 @@ RELAXNG
       @relaxng =<<RELAXNG
 #% xhtml output model, part of SiSU and distributed under the same license
 default namespace = ""
-namespace xlink = "http://www.w3.org/1999/xlink"
+namespace xl = "http://www.w3.org/1999/xlink"
 start =
   element document {
     element head {
@@ -823,8 +823,8 @@ start =
            attribute class { xsd:NCName },
            (text
             | element link {
-                attribute xlink:href { xsd:anyURI },
-                attribute xlink:type { xsd:NCName },
+                attribute xl:href { xsd:anyURI },
+                attribute xl:type { xsd:NCName },
                 xsd:anyURI
               })+
          }
@@ -923,10 +923,10 @@ start =
                   attribute alt { text }?,
                   attribute height { xsd:integer }?,
                   attribute width { xsd:integer }?,
-                  attribute xlink:actuate { xsd:NCName },
-                  attribute xlink:href { text },
-                  attribute xlink:show { xsd:NCName },
-                  attribute xlink:type { xsd:NCName }
+                  attribute xl:actuate { xsd:NCName },
+                  attribute xl:href { text },
+                  attribute xl:show { xsd:NCName },
+                  attribute xl:type { xsd:NCName }
                 }
               | element sub { text })+
            })+,
@@ -954,8 +954,8 @@ sup = element sup { xsd:NCName }
 i = element i { (text | b | br | sup)+ }
 link =
   element link {
-    attribute xlink:href { xsd:anyURI },
-    attribute xlink:type { xsd:NCName },
+    attribute xl:href { xsd:anyURI },
+    attribute xl:type { xsd:NCName },
     (text | b | i | sup)+
   }
 b = element b { (text | en | i | link | sup)+ }
