@@ -244,6 +244,9 @@ module SiSU_Screen
         %{#{@cX.off} } +
         %{#{@cX.cyan}nav only: #{@txt[4]}#{@cX.off}.}
     end
+    def grey
+      puts "#{@cX.grey}#{@txt[0]}#{@cX.off} #{@cX.cyan}#{@txt[1]}#{@cX.off}"
+    end
     def txt_white
       puts "\t#{@cX.white}#{@txt[0]}#{@cX.off} #{@cX.white}#{@txt[1]}#{@cX.off}"
     end
