@@ -68,8 +68,8 @@ module SiSU_SimpleXML_ModelSax
     include SiSU_Param
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env
-  require_relative 'dal_doc_str'                        # dal_doc_str.rb
-  require_relative 'shared_xml'                         # shared_xml.rb
+  require_relative 'ao_doc_str'                         # ao_doc_str.rb
+  require_relative 'xml_shared'                         # xml_shared.rb
     include SiSU_XML_Munge
   require_relative 'shared_sem'                         # shared_sem.rb
   require_relative 'xml_format'                         # xml_format.rb
@@ -109,9 +109,9 @@ module SiSU_SimpleXML_ModelSax
       end
     end
     def read_fnm
-      dal=[]
+      ao=[]
       if FileTest.file?("#{Dir.pwd}/#{@opt.fns}")
-        dal=IO.readlines("#{Dir.pwd}/#{@opt.fns}","\n\n")
+        ao=IO.readlines("#{Dir.pwd}/#{@opt.fns}","\n\n")
       else STDERR.puts 'Error'
       end
     end
@@ -138,7 +138,7 @@ module SiSU_SimpleXML_ModelSax
       end
     end
     class Scroll
-      require_relative 'shared_txt'                     # shared_txt.rb
+      require_relative 'txt_shared'                     # txt_shared.rb
       require_relative 'css'                            # css.rb
         include SiSU_TextUtils
       @@xml={ body: [], open: [], close: [], head: [] }
@@ -276,7 +276,7 @@ WOK
         (0..6).each { |x| @cont[x]=@level[x]=false }
         (4..6).each { |x| @xml_contents_close[x]='' }
         @data.each do |para|
-          data << SiSU_DAL_DocumentStructureExtract::Structure.new(@md,para).structure #takes on Mx marks
+          data << SiSU_AO_DocumentStructureExtract::Structure.new(@md,para).structure #takes on Mx marks
         end
         data.each do |para|
           if para !~/^\s*(?:%+ |<:code>)/
