@@ -81,8 +81,8 @@ module SiSU_TeX
     require_relative 'sysenv'                           # sysenv.rb
       include SiSU_Env
     include SiSU_Viz
-    require_relative 'dal'                              # dal.rb
-      include SiSU_DAL
+    require_relative 'ao'                               # ao.rb
+      include SiSU_AO
     include SiSU_TeX
     def initialize(opt)
       @opt=opt
@@ -126,9 +126,9 @@ module SiSU_TeX
         $flag=@md.opt.cmd                                                          #introduced to pass 0 for no object citation numbers... to texpdf_format
         directories
                                                                                #% needed needs to be reprogrammed !!!
-        dal_array=SiSU_DAL::Source.new(@opt).get # dal file drawn here
+        ao_array=SiSU_AO::Source.new(@opt).get # ao file drawn here
         SiSU_TeX::Source::LaTeXcreate.new(@particulars).songsheet
-        dal_array=''
+        ao_array=''
         pwd=Dir.pwd
         SiSU_TeX::Source::LaTeXtoPdf.new(@md,@particulars.env).latexrun_selective
         Dir.chdir(pwd)
@@ -339,7 +339,7 @@ module SiSU_TeX
         @particulars=particulars
         @md=@particulars.md
         @env=SiSU_Env::InfoEnv.new(@md.fns) #@env=@particulars.env
-        @data=@particulars.dal_array # dal file drawn here
+        @data=@particulars.ao_array # ao file drawn here
         @st={ tex: {} }
         @tex_ml=SiSU_TeX_Pdf::UseTeX.new(@md)
         @vz=SiSU_Viz::Defaults.new
@@ -1042,7 +1042,7 @@ module SiSU_TeX
                   file[:landscape].puts morph,"\n"
                 end
               end
-            elsif morph.class.inspect =~ /SiSU_DAL_DocumentStructure/ \
+            elsif morph.class.inspect =~ /SiSU_AO_DocumentStructure/ \
             and morph.tmp \
             and morph.tmp.is_a?(String)
               if morph.is !=:code \
