@@ -60,14 +60,14 @@
 
 =end
 module SiSU_Wikispeak
-  require_relative 'dal'                                # dal.rb
+  require_relative 'ao'                                 # ao.rb
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env
   include SiSU_Param
   include SiSU_Viz
   require_relative 'plaintext_format'                   # plaintext_format.rb
     include Format
-  require_relative 'shared_txt'
+  require_relative 'txt_shared'
   @@alt_id_count,@@alt_id_count,@@tablehead,@@number_of_cols=0,0,0,0
   @@tablefoot=''
   class Source
@@ -90,8 +90,8 @@ module SiSU_Wikispeak
         || @opt.act[:maintenance][:set]==:on)
           SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{@env.path.output_tell}/#{@md.fnb}/#{@md.fn[:wiki]}").flow
         end
-        @dal_array=SiSU_DAL::Source.new(@opt).get # dal file drawn here
-        SiSU_Wikispeak::Source::Scroll.new(@dal_array,@md).songsheet
+        @ao_array=SiSU_AO::Source.new(@opt).get # ao file drawn here
+        SiSU_Wikispeak::Source::Scroll.new(@ao_array,@md).songsheet
       rescue
         SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
@@ -149,7 +149,7 @@ module SiSU_Wikispeak
       end
     end
     class Scroll <Source
-      require_relative 'shared_txt'                     # shared_txt.rb
+      require_relative 'txt_shared'                     # txt_shared.rb
         include SiSU_TextUtils
       @@endnotes_para=[]
       @@wiki={ body: [], open: [], close: [], head: [], metadata: [], tail: [], endnotes: [] }
